@@ -10,11 +10,19 @@
 
 # The log should be imported first so that the Pyomo LogHandler can be
 # set up as soon as possible
-import pyomo.common.log
+from . import log
 
-import pyomo.common.config
-from pyomo.common.errors import DeveloperError
-from pyomo.common._task import pyomo_api, PyomoAPIData, PyomoAPIFactory
-from pyomo.common._command import pyomo_command, get_pyomo_commands
-from pyutilib.factory.executable import register_executable, registered_executable, unregister_executable
-from pyutilib.factory.factory import Factory, CachedFactory
+from pyutilib.factory.factory import (
+    Factory, CachedFactory
+)
+
+from .fileutils import (
+    Executable, Library,
+    # The following will be deprecated soon
+    register_executable, registered_executable, unregister_executable
+)
+from . import config
+from .deprecation import deprecated
+from .errors import DeveloperError
+from ._task import pyomo_api, PyomoAPIData, PyomoAPIFactory
+from ._command import pyomo_command, get_pyomo_commands
