@@ -25,3 +25,10 @@ class DeveloperError(NotImplementedError):
                  % ( repr(self.parameter), ) )
 
 
+class InfeasibleConstraintException(Exception):
+    """
+    Exception class used by Pyomo transformations to indicate
+    that an infeasible constraint has been identified (e.g. in
+    the course of range reduction).
+    """
+    pass
