@@ -7,7 +7,7 @@
 #  rights in this software.
 #  This software is distributed under the 3-clause BSD License.
 #  ___________________________________________________________________________
-
+import copy
 from six import PY3, iteritems, advance_iterator
 from pyomo.common import DeveloperError
 
@@ -47,6 +47,29 @@ class _IndexedComponent_slice(object):
         set_attr('key_errors_generate_exceptions', True)
         set_attr('attribute_errors_generate_exceptions', True)
 
+    def __getstate__(self):
+        """Serialize this object.
+
+        In general, we would not need to implement this (the object does
+        not leverage ``__slots__``).  However, because we have a
+        "blanket" implementation of :py:meth:`__getattr__`, we need to
+        explicitly implement these to avoid "accidentally" extending or
+        evaluating this slice."""
+        return dict(
+            (k,getattr(self,k)) for k in self.__dict__)
+
+    def __setstate__(self, state):
+        """Deserialize the state into this object. """
+        set_attr = super(_IndexedComponent_slice, self).__setattr__
+        for k,v in iteritems(state):
+            set_attr(k,v)
+
+    def __deepcopy__(self, memo):
+        """Deepcopy this object (leveraging :py:meth:`__getstate__`)"""
+        ans = memo[id(self)] = self.__class__.__new__(self.__class__)
+        ans.__setstate__(copy.deepcopy(self.__getstate__(), memo))
+        return ans
+
     def __iter__(self):
         """Return an iterator over this slice"""
         return _IndexedComponent_slice_iter(self)
@@ -158,6 +181,10 @@ class _IndexedComponent_slice(object):
         ans._call_stack = list(self._call_stack)
         return ans
 
+    def index_wildcard_keys(self):
+        _iter = _IndexedComponent_slice_iter(self, iter_over_index=True)
+        return (_iter.get_last_index_wildcards() for _ in _iter)
+
     def wildcard_keys(self):
         _iter = self.__iter__()
         return (_iter.get_last_index_wildcards() for _ in _iter)
@@ -181,14 +208,18 @@ class _slice_generator(object):
     Iterate through the component index and yield the component data
     values that match the slice template.
     """
-    def __init__(self, component, fixed, sliced, ellipsis):
+    def __init__(self, component, fixed, sliced, ellipsis, iter_over_index):
         self.component = component
         self.fixed = fixed
         self.sliced = sliced
         self.ellipsis = ellipsis
+        self.iter_over_index = iter_over_index
 
         self.explicit_index_count = len(fixed) + len(sliced)
-        self.component_iter = component.__iter__()
+        if iter_over_index:
+            self.component_iter = component.index_set().__iter__()
+        else:
+            self.component_iter = component.__iter__()
         self.last_index = None
 
     def next(self):
@@ -227,7 +258,10 @@ class _slice_generator(object):
                 # Note: it is important to use __getitem__, as the
                 # derived class may implement a non-standard storage
                 # mechanism (e.g., Param)
-                return self.component[index]
+                if (not self.iter_over_index) or index in self.component:
+                    return self.component[index]
+                else:
+                    return None
 
 
 # Mock up a callable object with a "check_complete" method
@@ -242,17 +276,20 @@ class _NotIterable(object): pass
 
 
 class _IndexedComponent_slice_iter(object):
-    def __init__(self, component_slice, advance_iter=_advance_iter):
+    def __init__(self, component_slice, advance_iter=_advance_iter,
+                 iter_over_index=False):
         # _iter_stack holds a list of elements X where X is either an
         # _slice_generator iterator (if this level in the hierarchy is a
         # slice) or None (if this level is either a SimpleComponent,
         # attribute, method, or is explicitly indexed).
         self._slice = component_slice
         self.advance_iter = advance_iter
+        self._iter_over_index = iter_over_index
         call_stack = self._slice._call_stack
         self._iter_stack = [None]*len(call_stack)
         if call_stack[0][0] == _IndexedComponent_slice.slice_info:
-            self._iter_stack[0] = _slice_generator(*call_stack[0][1])
+            self._iter_stack[0] = _slice_generator(
+                *call_stack[0][1], iter_over_index=self._iter_over_index)
         elif call_stack[0][0] == _IndexedComponent_slice.set_item:
             assert len(call_stack) == 1
             # defer creating the iterator until later
@@ -304,7 +341,8 @@ class _IndexedComponent_slice_iter(object):
                         # things that match.  We will allow users to
                         # (silently) ignore any attribute errors generated
                         # by concrete indices in the slice hierarchy...
-                        if self._slice.attribute_errors_generate_exceptions:
+                        if self._slice.attribute_errors_generate_exceptions \
+                           and not self._iter_over_index:
                             raise
                         break
                 elif _call[0] == _IndexedComponent_slice.get_item:
@@ -316,7 +354,8 @@ class _IndexedComponent_slice_iter(object):
                         # allow users to (silently) ignore any key
                         # errors generated by concrete indices in the
                         # slice hierarchy...
-                        if self._slice.key_errors_generate_exceptions:
+                        if self._slice.key_errors_generate_exceptions \
+                           and not self._iter_over_index:
                             raise
                         break
                     if _comp.__class__ is _IndexedComponent_slice:
@@ -326,7 +365,9 @@ class _IndexedComponent_slice_iter(object):
                         # _IndexedComponent_slice object)
                         assert len(_comp._call_stack) == 1
                         self._iter_stack[idx] = _slice_generator(
-                            *_comp._call_stack[0][1])
+                            *_comp._call_stack[0][1],
+                            iter_over_index=self._iter_over_index
+                        )
                         try:
                             _comp = self.advance_iter(self._iter_stack[idx])
                         except StopIteration:
@@ -348,7 +389,8 @@ class _IndexedComponent_slice_iter(object):
                         # allow users to (silently) ignore any key
                         # errors generated by concrete indices in the
                         # slice hierarchy...
-                        if self._slice.call_errors_generate_exceptions:
+                        if self._slice.call_errors_generate_exceptions \
+                           and not self._iter_over_index:
                             raise
                         break
                 elif _call[0] == _IndexedComponent_slice.set_attribute:
@@ -374,7 +416,9 @@ class _IndexedComponent_slice_iter(object):
                     # iteration).  This is indicated by setting the
                     # _iter_stack value to _NotIterable.
                     if self._iter_stack[idx] is _NotIterable:
-                        _iter = _slice_generator(*_call[1])
+                        _iter = _slice_generator(
+                            *_call[1], iter_over_index=self._iter_over_index
+                        )
                         while True:
                             # This ends when the _slice_generator raises
                             # a StopIteration exception
@@ -400,7 +444,8 @@ class _IndexedComponent_slice_iter(object):
                         # allow users to (silently) ignore any key
                         # errors generated by concrete indices in the
                         # slice hierarchy...
-                        if self._slice.key_errors_generate_exceptions:
+                        if self._slice.key_errors_generate_exceptions \
+                           and not self._iter_over_index:
                             raise
                         break
                     if _tmp.__class__ is _IndexedComponent_slice:
