@@ -8,21 +8,20 @@
 #  This software is distributed under the 3-clause BSD License.
 #  ___________________________________________________________________________
 
-from pyomo.util.plugin import alias
-from pyomo.core import Constraint, Objective, NumericConstant
-from pyomo.core.base.expr import _ExpressionBase
+from pyomo.core.expr.current import ExpressionBase
+from pyomo.core.expr.numvalue import as_numeric
+from pyomo.core import Constraint, Objective
 from pyomo.core.base.var import Var, _VarData
 from pyomo.core.base.util import sequence
 from pyomo.core.plugins.transform.hierarchy import IsomorphicTransformation
 
 
+@TransformationFactory.register('core.remove_fixed_vars', doc="Create an equivalent model that omits all fixed variables.")
 class EliminateFixedVars(IsomorphicTransformation):
     """
     Create an equivalent model that omits all fixed variables.
     """
 
-    alias('core.remove_fixed_vars', doc="Create an equivalent model that omits all fixed variables.")
-
     def __init__(self, **kwds):
         kwds['name'] = "eliminate_fixed_vars"
         super(EliminateFixedVars, self).__init__(**kwds)
@@ -67,15 +66,16 @@ class EliminateFixedVars(IsomorphicTransformation):
 
     def _fix_vars(self, expr, model):
         """ Walk through the S-expression, fixing variables. """
+        # TODO - Change this to use a visitor pattern!
         if expr._args is None:
             return expr
         _args = []
         for i in range(len(expr._args)):
-            if isinstance(expr._args[i],_ExpressionBase):
+            if isinstance(expr._args[i],ExpressionBase):
                 _args.append( self._fix_vars(expr._args[i], model) )
             elif (isinstance(expr._args[i],Var) or isinstance(expr._args[i],_VarData)) and expr._args[i].fixed:
                 if expr._args[i].value != 0.0:
-                    _args.append( NumericConstant(None,None,expr._args[i].value) )
+                    _args.append( as_numeric(expr._args[i].value) )
             else:
                 _args.append( expr._args[i] )
         expr._args = _args
