@@ -192,6 +192,7 @@ SolverFactory = SolverFactoryClass('solver type')
 def check_available_solvers(*args):
     from pyomo.solvers.plugins.solvers.GUROBI import GUROBISHELL
     from pyomo.solvers.plugins.solvers.BARON import BARONSHELL
+    from pyomo.solvers.plugins.solvers.mosek_direct import MosekDirect
 
     logging.disable(logging.WARNING)
 
@@ -211,6 +212,9 @@ def check_available_solvers(*args):
         elif (arg[0] == "baron") and \
            (not BARONSHELL.license_is_valid()):
             available = False
+        elif (arg[0] == "mosek") and \
+           (not MosekDirect.license_is_valid()):
+            available = False
         else:
             available = \
                 (opt.available(exception_flag=False)) and \
