@@ -1,12 +1,14 @@
-from __future__ import division
-#  _________________________________________________________________________
+#  ___________________________________________________________________________
 #
 #  Pyomo: Python Optimization Modeling Objects
-#  Copyright (c) 2014 Sandia Corporation.
-#  Under the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,
-#  the U.S. Government retains certain rights in this software.
-#  This software is distributed under the BSD License.
-#  _________________________________________________________________________
+#  Copyright 2017 National Technology and Engineering Solutions of Sandia, LLC
+#  Under the terms of Contract DE-NA0003525 with National Technology and
+#  Engineering Solutions of Sandia, LLC, the U.S. Government retains certain
+#  rights in this software.
+#  This software is distributed under the 3-clause BSD License.
+#  ___________________________________________________________________________
+
+from __future__ import division
 
 import os
 import logging
@@ -116,7 +118,6 @@ def ExtractInternalNodeSolutionsWithSlamming(ph):
     #   assume that the argument was a json file with slamming instructions.
     # This will ignore suffixes we don't care about.
     # If there are no instructions use xbar.
-    # If they have given non-booleans, stack dump.
     # Note: there is an implicit pecking order.
     print ("For x-hat, using slamming suffixes in",ph._xhat_method)
     slamdict = {}
@@ -534,7 +535,7 @@ class _PHBoundBase(object):
 
         print("")
         best_inner_bound = None
-        if len(self._outer_bound_history) > 0:
+        if len(self._inner_bound_history) > 0: # dlw May 2016
             if self._is_minimizing:
                 best_inner_bound = min(self._inner_bound_history.values())
             else:
