@@ -2,8 +2,8 @@
 #
 #  Pyomo: Python Optimization Modeling Objects
 #  Copyright 2017 National Technology and Engineering Solutions of Sandia, LLC
-#  Under the terms of Contract DE-NA0003525 with National Technology and 
-#  Engineering Solutions of Sandia, LLC, the U.S. Government retains certain 
+#  Under the terms of Contract DE-NA0003525 with National Technology and
+#  Engineering Solutions of Sandia, LLC, the U.S. Government retains certain
 #  rights in this software.
 #  This software is distributed under the 3-clause BSD License.
 #  ___________________________________________________________________________
@@ -20,7 +20,7 @@ from pyutilib.misc.timing import tic, toc
 from pyomo.core import (
     minimize, value, TransformationFactory,
     ComponentUID, Block, Constraint, ConstraintList,
-    Param, Var, VarList, Set, Objective, Suffix, 
+    Param, Var, VarList, Set, Objective, Suffix,
     Binary, Boolean,
     Integers, PositiveIntegers, NonPositiveIntegers,
     NegativeIntegers, NonNegativeIntegers, IntegerInterval,
@@ -29,18 +29,12 @@ from pyomo.opt import (
     SolverFactory, SolverStatus, TerminationCondition, ProblemFormat )
 from pyomo.pysp import phextension
 from pyomo.solvers.plugins.smanager.phpyro import SolverManager_PHPyro
-from pyomo.util.plugin import SingletonPlugin, implements
+from pyomo.common.plugin import SingletonPlugin, implements
 
-from pyomo.repn.compute_ampl_repn import (
-    preprocess_block_constraints as ampl_preprocess_block_constraints,
-    preprocess_block_objectives as ampl_preprocess_block_objectives,
-)
-from pyomo.repn.compute_canonical_repn import (
-    preprocess_block_constraints as canonical_preprocess_block_constraints,
-    preprocess_block_objectives as canonical_preprocess_block_objectives,
-)
+from pyomo.repn.standard_repn import (preprocess_block_constraints,
+                                      preprocess_block_objectives)
 from pyomo.pysp.phsolverserverutils import (
-    InvocationType, 
+    InvocationType,
     transmit_external_function_invocation,
     transmit_external_function_invocation_to_worker )
 from pyomo.pysp.convergence import NormalizedTermDiffConvergence
@@ -103,7 +97,7 @@ def get_modified_instance( ph, scenario_tree, scenario_or_bundle, **options):
     b.abs_int_vars = VarList(within=NonNegativeIntegers)
     b.abs_binary_vars = VarList(within=Binary)
 
-    # Note: the var_ids are on the ORIGINAL scenario models 
+    # Note: the var_ids are on the ORIGINAL scenario models
     rootNode = scenario_tree.findRootNode()
     var_ids = list(iterkeys(rootNode._variable_datas))
 
@@ -173,11 +167,8 @@ def get_modified_instance( ph, scenario_tree, scenario_or_bundle, **options):
     if FALLBACK_ON_BRUTE_FORCE_PREPROCESS:
         model.preprocess()
     else:
-        if ph._solver.problem_format() == ProblemFormat.nl:
-            ampl_preprocess_block_constraints(b)
-        else:
-            _map = {}
-            canonical_preprocess_block_constraints(b, _map)
+        _map = {}
+        preprocess_block_constraints(b, idMap=_map)
 
     # Note: we wait to deactivate the objective until after we
     # preprocess so that the obective is correctly processed.
@@ -217,16 +208,13 @@ def get_dual_values(solver, model):
         if FALLBACK_ON_BRUTE_FORCE_PREPROCESS:
             model.preprocess()
         else:
-            if solver.problem_format() == ProblemFormat.nl:
-                ampl_preprocess_block_constraints(model._interscenario_plugin)
-            else:
-                _map = {}
-                canonical_preprocess_block_constraints(
-                    model._interscenario_plugin, _map )
+            _map = {}
+            preprocess_block_constraints(
+                model._interscenario_plugin, idMap=_map)
 
         #SOLVE
         results = solver.solve(model, warmstart=True)
-        ss = results.solver.status 
+        ss = results.solver.status
         tc = results.solver.termination_condition
         #self.timeInSolver += results['Solver'][0]['Time']
         if ss == SolverStatus.ok and tc in _acceptable_termination_conditions:
@@ -254,14 +242,14 @@ def get_dual_values(solver, model):
             xfrm.apply(model, inplace=True, undo=True)
         else:
             xfrm.apply_to(model, undo=True)
-        
+
     else:
         # return the duals
         for varid in model._interscenario_plugin.STAGE1VAR:
             duals[varid] = model.dual[_con[varid]]
 
     return duals
-    
+
 get_dual_values.discrete_stage2_vars = {}
 
 
@@ -295,13 +283,9 @@ def solve_separation_problem(solver, model, fallback):
     if FALLBACK_ON_BRUTE_FORCE_PREPROCESS:
         model.preprocess()
     else:
-        if solver.problem_format() == ProblemFormat.nl:
-            ampl_preprocess_block_objectives(_block)
-            ampl_preprocess_block_constraints(_block)
-        else:
-            _map = {}
-            canonical_preprocess_block_objectives(_block,_map)
-            canonical_preprocess_block_constraints(_block,_map)
+        _map = {}
+        preprocess_block_objectives(_block, idMap=_map)
+        preprocess_block_constraints(_block, idMap=_map)
 
     #SOLVE
     output_buffer = StringIO()
@@ -316,7 +300,7 @@ def solve_separation_problem(solver, model, fallback):
     finally:
         pyutilib.misc.reset_redirect()
 
-    ss = results.solver.status 
+    ss = results.solver.status
     tc = results.solver.termination_condition
     #self.timeInSolver += results['Solver'][0]['Time']
     if ss == SolverStatus.ok and tc in _acceptable_termination_conditions:
@@ -369,11 +353,8 @@ def solve_separation_problem(solver, model, fallback):
     if FALLBACK_ON_BRUTE_FORCE_PREPROCESS:
         pass
     else:
-        if solver.problem_format() == ProblemFormat.nl:
-            ampl_preprocess_block_objectives(_block)
-        else:
-            _map = {}
-            canonical_preprocess_block_objectives(_block,_map)
+        _map = {}
+        preprocess_block_objectives(_block, idMap=_map)
     return ans
 
 
@@ -392,7 +373,7 @@ def add_new_cuts( ph, scenario_tree, scenario_or_bundle,
         expr = sum(
             2 * (_sep*(1-cut_scale))
               * (_src[i]() - (_par+_sep*(1-cut_scale)))
-            for i, (_sep, _par) in iteritems(cut) 
+            for i, (_sep, _par) in iteritems(cut)
             if abs(_sep) > epsilon*max(1,_par)
         )
         if expr is not 0:
@@ -424,15 +405,12 @@ def add_new_cuts( ph, scenario_tree, scenario_or_bundle,
     if FALLBACK_ON_BRUTE_FORCE_PREPROCESS:
         m.preprocess()
     else:
-        if ph._solver.problem_format() == ProblemFormat.nl:
-            ampl_preprocess_block_constraints(_block)
-        else:
-            _map = {}
-            canonical_preprocess_block_constraints(_block,_map)
+        _map = {}
+        preprocess_block_constraints(_block, idMap=_map)
 
     if resolve:
         results = ph._solver.solve(m, warmstart=True)
-        ss = results.solver.status 
+        ss = results.solver.status
         tc = results.solver.termination_condition
         #self.timeInSolver += results['Solver'][0]['Time']
         if ss == SolverStatus.ok and tc in _acceptable_termination_conditions:
@@ -451,8 +429,8 @@ def add_new_cuts( ph, scenario_tree, scenario_or_bundle,
             return None
 
 
-def solve_fixed_scenario_solutions( 
-        ph, scenario_tree, scenario_or_bundle, 
+def solve_fixed_scenario_solutions(
+        ph, scenario_tree, scenario_or_bundle,
         scenario_solutions, **model_options ):
 
     model = get_modified_instance(
@@ -501,18 +479,15 @@ def solve_fixed_scenario_solutions(
         for var_id, var_value in iteritems(var_values):
             _param[var_id] = var_value
 
-        # TODO: We only need to update the CanonicalRepn for the binding
+        # TODO: We only need to update the StandardRepn for the binding
         # constraints ... so we could save a LOT of time by not
         # preprocessing the whole model.
         #
         if FALLBACK_ON_BRUTE_FORCE_PREPROCESS:
             model.preprocess()
         else:
-            if ph._solver.problem_format() == ProblemFormat.nl:
-                ampl_preprocess_block_constraints(_block)
-            else:
-                var_id_map = {}
-                canonical_preprocess_block_constraints(_block, var_id_map)
+            var_id_map = {}
+            preprocess_block_constraints(_block, idMap=var_id_map)
 
         toc("preprocessed scenario %s" % ( scenario_or_bundle._name, ))
         output_buffer = StringIO()
@@ -529,7 +504,7 @@ def solve_fixed_scenario_solutions(
         toc("solved solution from scenario set %s on scenario %s" %
             ( scenario_name_list, scenario_or_bundle._name, ))
 
-        ss = results.solver.status 
+        ss = results.solver.status
         tc = results.solver.termination_condition
         #self.timeInSolver += results['Solver'][0]['Time']
         if ss == SolverStatus.ok and tc in _acceptable_termination_conditions:
@@ -562,14 +537,14 @@ def solve_fixed_scenario_solutions(
                 if cut == '????':
                     if ph._solver.problem_format() != ProblemFormat.nl:
                         model.preprocess()
-                        #ampl_preprocess_block_objectives(_block)
-                        #ampl_preprocess_block_constraints(_block)
+                        #preprocess_block_objectives(_block)
+                        #preprocess_block_constraints(_block)
                     cut = solve_separation_problem(ipopt, model, False)
             else:
                 cut = "X  "
             cutlist.append( cut )
             toc("solved separation problem for solution from scenario set "
-                "%s on scenario %s" % 
+                "%s on scenario %s" %
                 ( scenario_name_list, scenario_or_bundle._name, ))
         else:
             state = 2 #'NONOPTIMAL'
@@ -595,7 +570,7 @@ def solve_fixed_scenario_solutions(
 
 class InterScenarioPlugin(SingletonPlugin):
 
-    implements(phextension.IPHExtension) 
+    implements(phextension.IPHExtension)
 
     def __init__(self):
         self.enableRhoUpdates = True
@@ -745,7 +720,7 @@ class InterScenarioPlugin(SingletonPlugin):
                 _min = rootNode._minimums[_id]
                 if rho < self.epsilon and _max - _min > self.epsilon:
                     print( "InterScenario plugin: triggered by variable "
-                           "divergence with rho==0 (%s: %s; [%s, %s])" 
+                           "divergence with rho==0 (%s: %s; [%s, %s])"
                            % (_id, rho, _max, _min))
                     run = True
                     break
@@ -803,10 +778,10 @@ class InterScenarioPlugin(SingletonPlugin):
                     ','.join(soln[1])
                 ))
 
-        scenarioCosts = [ ph._scenario_tree.get_scenario(x)._cost 
+        scenarioCosts = [ ph._scenario_tree.get_scenario(x)._cost
                           for s in self.unique_scenario_solutions
                           for x in s[1] ]
-        scenarioProb =  [ ph._scenario_tree.get_scenario(x)._probability 
+        scenarioProb =  [ ph._scenario_tree.get_scenario(x)._probability
                           for s in self.unique_scenario_solutions
                           for x in s[1] ]
         _avg = sum( scenarioProb[i]*c for i,c in enumerate(scenarioCosts) )
@@ -831,7 +806,7 @@ class InterScenarioPlugin(SingletonPlugin):
         #cutCount = len(self.feasibility_cuts)
         if self.enableFeasibilityCuts:
             self.feasibility_cuts = cuts
-        cutCount = sum( sum( 1 for x in c if type(x) is tuple 
+        cutCount = sum( sum( 1 for x in c if type(x) is tuple
                              and  x[0]>self.cutThreshold_minDiff )
                         for c in cuts )
         subProblemCount = sum(len(c) for c in cuts)
@@ -846,7 +821,7 @@ class InterScenarioPlugin(SingletonPlugin):
             # Tell ph that we may have a good opter bound
             ph._update_reported_bounds(outer=self.average_solution)
 
-            if ( cutCount > self.recutThreshold*(subProblemCount-len(cuts)) 
+            if ( cutCount > self.recutThreshold*(subProblemCount-len(cuts))
                  and ( _del_avg is None or
                        _del_avg > self.iteration0RecutBoundImprovement )):
                 # Bypass RHO updates and check for more cuts
@@ -989,7 +964,7 @@ class InterScenarioPlugin(SingletonPlugin):
     def _distribute_cuts(self, ph, resolve=False):
         totalCuts = 0
         cutObj = sorted( c[0] for x in self.feasibility_cuts for c in x
-                         if type(c) is tuple 
+                         if type(c) is tuple
                          and c[0] > self.cutThreshold_minDiff )
         if cutObj:
             allCutThreshold = cutObj[
@@ -1087,12 +1062,11 @@ class InterScenarioPlugin(SingletonPlugin):
                     continue
                 for scenario in get_scenarios(problem):
                     scenario._cost = ans[1]
-                    assert( sorted(ans[0]) == 
+                    assert( sorted(ans[0]) ==
                             sorted(scenario._x[rootNode._name]) )
                     scenario._x[rootNode._name] = ans[0] #[_vid] = _vval
             ph.update_variable_statistics()
 
-    
     def _compute_objective(self, partial_obj_values, probability):
         obj_values = []
         for soln_id in xrange(len( self.unique_scenario_solutions )):
@@ -1221,7 +1195,7 @@ class InterScenarioPlugin(SingletonPlugin):
             self.x_deviation = dict(
                 ( v,
                   max(s[0][v] for s in self.unique_scenario_solutions)
-                  - min(s[0][v] for s in self.unique_scenario_solutions) ) 
+                  - min(s[0][v] for s in self.unique_scenario_solutions) )
                 for v in xbar )
 
         max_dual = dict((v,0.) for v in xbar)
@@ -1323,7 +1297,7 @@ class InterScenarioPlugin(SingletonPlugin):
             loginfo[k] = \
                 "%4d: %6.1f [%7.1f, %7.1f] %7.1f;  " \
                 "%6.1f [%6.1f, %6.1f] %6.1f;  RHO %7.2f : %%7.2f" % (
-                k, 
+                k,
                 d_avg, d_min, d_max, d_stdev,
                 x_avg, x_min, x_max, x_stdev,
                 weighted_rho[k] )
