@@ -278,7 +278,7 @@ def EXTERNAL_initialize_for_benders(manager,
     for variable_id in rootnode._variable_ids:
         vardata = scenario_bySymbol[variable_id]
         # derived variables might be Expression objects
-        if not vardata.is_expression():
+        if not vardata.is_expression_type():
             tight_bounds = vardata.bounds
             domain = vardata.domain
             vardata.domain = Reals
@@ -595,8 +595,6 @@ class BendersAlgorithm(PySPConfiguredObject):
             self.cleanup_subproblems()
         if self._manager_solver is not None:
             self._manager_solver.close()
-        if self._master_solver is not None:
-            self._master_solver.deactivate()
         self._manager = None
         self._manager_solver = None
         self._master_solver = None
