@@ -132,7 +132,7 @@ class TestCPXLPOrdering(unittest.TestCase):
         components["obj"] = Objective(expr=model.a)
         components["con1"] = Constraint(expr=model.a >= 0)
         components["con2"] = Constraint(expr=model.a <= 1)
-        components["con3"] = Constraint(expr=0 <= model.a <= 1)
+        components["con3"] = Constraint(expr=(0, model.a, 1))
         components["con4"] = Constraint([1,2], rule=lambda m, i: model.a == i)
 
         # add components in random order
@@ -151,7 +151,7 @@ class TestCPXLPOrdering(unittest.TestCase):
         components["obj"] = Objective(expr=model.a)
         components["con1"] = Constraint(expr=model.a >= 0)
         components["con2"] = Constraint(expr=model.a <= 1)
-        components["con3"] = Constraint(expr=0 <= model.a <= 1)
+        components["con3"] = Constraint(expr=(0, model.a, 1))
         components["con4"] = Constraint([1,2], rule=lambda m, i: model.a == i)
 
         # add components in random order
@@ -193,9 +193,8 @@ class TestCPXLP_writer(unittest.TestCase):
 
         baseline_fname, test_fname = self._get_fnames()
         self._cleanup(test_fname)
-        self.assertRaisesRegexp(
+        self.assertRaises(
             KeyError,
-            "'a' is not part of the model",
             model.write, test_fname, format='lp')
         self._cleanup(test_fname)
 
@@ -231,9 +230,8 @@ class TestCPXLP_writer(unittest.TestCase):
 
         baseline_fname, test_fname = self._get_fnames()
         self._cleanup(test_fname)
-        self.assertRaisesRegexp(
+        self.assertRaises(
             KeyError,
-            "'other.a' exists within Foo 'other'",
             model.write, test_fname, format='lp')
         self._cleanup(test_fname)
 
