@@ -2,8 +2,8 @@
 #
 #  Pyomo: Python Optimization Modeling Objects
 #  Copyright 2017 National Technology and Engineering Solutions of Sandia, LLC
-#  Under the terms of Contract DE-NA0003525 with National Technology and 
-#  Engineering Solutions of Sandia, LLC, the U.S. Government retains certain 
+#  Under the terms of Contract DE-NA0003525 with National Technology and
+#  Engineering Solutions of Sandia, LLC, the U.S. Government retains certain
 #  rights in this software.
 #  This software is distributed under the 3-clause BSD License.
 #  ___________________________________________________________________________
@@ -17,9 +17,9 @@ from os.path import dirname, abspath, exists, join
 import sys
 
 import pyutilib.dev.runtests
-import pyomo.util
+import pyomo.common
 
-@pyomo.util.pyomo_command('test.pyomo', "Execute Pyomo tests")
+@pyomo.common.pyomo_command('test.pyomo', "Execute Pyomo tests")
 def runPyomoTests(argv=None):
     if argv is None:
         argv = sys.argv
