@@ -62,7 +62,8 @@ def _validate_file_name(cplex, filename, description):
                 "CPLEX or remove the space from the %s path."
                 % (description, filename, description))
     return filename
-_validate_file_name.allowed_characters = r"a-zA-Z0-9 :\.\-_\%s" % (os.path.sep,)
+_validate_file_name.allowed_characters = r"a-zA-Z0-9 ~:\.\-_\%s" % (
+    os.path.sep,)
 _validate_file_name.illegal_characters = re.compile(
     '[^%s]' % (_validate_file_name.allowed_characters,))
 
@@ -259,14 +260,14 @@ class CPLEXSHELL(ILMLicensedSystemCallSolver):
                           % (end_time-start_time))
 
     def _default_executable(self):
-        executable = pyomo.common.registered_executable("cplex")
-        if executable is None:
+        executable = pyomo.common.Executable("cplex")
+        if not executable:
             logger.warning("Could not locate the 'cplex' executable"
                            ", which is required for solver %s"
                            % self.name)
             self.enable = False
             return None
-        return executable.get_path()
+        return executable.path()
 
     def _get_version(self):
         """
@@ -805,6 +806,3 @@ class MockCPLEX(CPLEXSHELL,MockMIP):
         return MockMIP._execute_command(self, cmd)
 
 
-pyomo.common.register_executable(name="cplex")
-pyomo.common.register_executable(name="cplexamp")
-
