@@ -8,10 +8,10 @@
 #  This software is distributed under the 3-clause BSD License.
 #  ___________________________________________________________________________
 
+import pyomo.kernel as pmo
 from pyomo.core import ConcreteModel, Param, Var, Expression, Objective, Constraint, NonNegativeReals
 from pyomo.solvers.tests.models.base import _BaseTestModel, register_model
 
-
 @register_model
 class LP_constant_objective1(_BaseTestModel):
     """
@@ -37,5 +37,17 @@ class LP_constant_objective1(_BaseTestModel):
     def warmstart_model(self):
         assert self.model is not None
         model = self.model
-        model.x = None
+        model.x.value = None
 
+@register_model
+class LP_constant_objective1_kernel(LP_constant_objective1):
+
+    def _generate_model(self):
+        self.model = pmo.block()
+        model = self.model
+        model._name = self.description
+
+        model.x = pmo.variable(domain=NonNegativeReals)
+        model.obj = pmo.objective(0.0)
+        model.con = pmo.linear_constraint(terms=[(model.x,1.0)],
+                                          rhs=1.0)
